Module closure_objects

Module closure_objects 

  • The objects for you to implement your closure, some is closures’ params, some is the return value that your closure should return.

Structs

SamplesInfo

Enums

FlacInternalDecoderError
The FLAC decoder internal error value for your on_error() closure to report.
FlacReadStatus
The result value for your on_read() closure to return