pub enum FlacEncoderErrorCode {
StreamEncoderOk = 0,
StreamEncoderUninitialized = 1,
StreamEncoderOggError = 2,
StreamEncoderVerifyDecoderError = 3,
StreamEncoderVerifyMismatchInAudioData = 4,
StreamEncoderClientError = 5,
StreamEncoderIOError = 6,
StreamEncoderFramingError = 7,
StreamEncoderMemoryAllocationError = 8,
}Expand description
The error code for FlacEncoderError
Variants
StreamEncoderOk = 0
- The encoder is in the normal OK state and samples can be processed.
StreamEncoderUninitialized = 1
- The encoder is in the uninitialized state; one of the FLAC__stream_encoder_init_*() functions must be called before samples can be processed.
StreamEncoderOggError = 2
- An error occurred in the underlying Ogg layer.
StreamEncoderVerifyDecoderError = 3
- An error occurred in the underlying verify stream decoder; check FLAC__stream_encoder_get_verify_decoder_state().
StreamEncoderVerifyMismatchInAudioData = 4
- The verify decoder detected a mismatch between the original audio signal and the decoded audio signal.
StreamEncoderClientError = 5
- One of the closures returned a fatal error.
StreamEncoderIOError = 6
- An I/O error occurred while opening/reading/writing a file.
StreamEncoderFramingError = 7
- An error occurred while writing the stream; usually, the
on_write()returned an error.
StreamEncoderMemoryAllocationError = 8
- Memory allocation failed