pub enum FlacAudioForm {
FrameArray,
ChannelArray,
}Expand description
The form of audio samples
Variants
FrameArray
- For the frame array, each audio frame is one sample per channel.
- For example, a stereo frame has two samples, one for left, and one for right.
ChannelArray
- For channel array, each element of the array is one channel of the audio.
- For example, if the audio is mono, the array only contains one element, that element is the only channel for the mono audio.